@@ -41,6 +41,9 @@ _CONNECT_TIMEOUT = 20.0
 class Connection(object): # TODO support auth for pooling
     """A connection to Mongo.
     """
+
+    # TODO consider deprecating these. or at least find a way for
+    # the default args to __init__ and paired to be properly documented.
     HOST = "localhost"
     PORT = 27017
     POOL_SIZE = 1
@@ -48,7 +51,8 @@ class Connection(object): # TODO support auth for pooling
     TIMEOUT = 1.0
 
     def __init__(self, host=None, port=None, pool_size=None,
-                 auto_start_request=None, timeout=None, _connect=True):
+                 auto_start_request=None, timeout=None, slave_okay=False,
+                 _connect=True):
         """Open a new connection to a Mongo instance at host:port.
 
         The resultant connection object has connection-pooling built in. It
@@ -75,6 +79,8 @@ class Connection(object): # TODO support auth for pooling
             connection-pool
           - `auto_start_request` (optional): automatically start a request
             on every operation - see documentation for `start_request`
+          - `slave_okay` (optional): is it okay to connect directly to and
+            perform queries on a slave instance
           - `timeout` (optional): max time to wait when attempting to acquire a
             connection from the connection pool before raising an exception -
             can be set to -1 to wait indefinitely
@@ -105,6 +111,7 @@ class Connection(object): # TODO support auth for pooling
         self.__port = None
 
         self.__nodes = [(host, port)]
+        self.__slave_okay = slave_okay
 
         # current request_id
         self.__id = 1
@@ -193,6 +200,9 @@ class Connection(object): # TODO support auth for pooling
         if result["ismaster"] == 1:
             return True
         else:
+            if "remote" not in result:
+                return False
+
             strings = result["remote"].split(":", 1)
             if len(strings) == 1:
                 port = self.PORT
@@ -264,6 +274,12 @@ class Connection(object): # TODO support auth for pooling
         """
         return self.__port
 
+    def slave_okay(self):
+        """Is it okay for this connection to connect directly to a slave?
+        """
+        return self.__slave_okay
+    slave_okay = property(slave_okay)
+
     def __find_master(self):
         """Create a new socket and use it to figure out who the master is.
 
@@ -289,6 +305,17 @@ class Connection(object): # TODO support auth for pooling
                         self.__port = port
                         _logger.debug("found master")
                         return
+                    if not master:
+                        if self.__slave_okay:
+                            self.__host = host
+                            self.__port = port
+                            _logger.debug("connecting to slave (slave_okay mode)")
+                            return
+
+                        raise ConfigurationError("trying to connect directly to"
+                                                 " slave %s:%r - must specify "
+                                                 "slave_okay to connect to "
+                                                 "slaves" % (host, port))
                     if master not in self.__nodes:
                         raise ConfigurationError(
                             "%r claims master is %r, "
