@@ -16,6 +16,7 @@
 
 import types
 import struct
+import warnings
 
 import pymongo
 import bson
@@ -23,6 +24,12 @@ from son import SON
 from code import Code
 from errors import InvalidOperation, OperationFailure, AutoReconnect
 
+_QUERY_OPTIONS = {
+    "tailable_cursor": 2,
+    "slave_okay": 4,
+    "oplog_replay": 8
+}
+
 
 class Cursor(object):
     """A cursor / iterator over Mongo query results.
@@ -38,6 +45,7 @@ class Cursor(object):
         self.__fields = fields
         self.__skip = skip
         self.__limit = limit
+        self.__slave_okay = collection.database().connection().slave_okay
         self.__ordering = None
         self.__explain = False
         self.__hint = None
@@ -53,12 +61,38 @@ class Cursor(object):
         if self.__id and not self.__killed:
             self.__die()
 
-    def __copy(self):
+    def rewind(self):
+        """Rewind this cursor to it's unevaluated state.
+
+        Reset this cursor if it has been partially or completely evaluated.
+        Any options that are present on the cursor will remain in effect.
+        Future iterating performed on this cursor will cause new queries to
+        be sent to the server, even if the resultant data has already been
+        retrieved by this cursor.
+        """
+        self.__data = []
+        self.__id = None
+        self.__connection_id = None
+        self.__retrieved = 0
+        self.__killed = False
+
+        return self
+
+    def clone(self):
+        """Get a clone of this cursor.
+
+        Returns a new Cursor instance with options matching those that have
+        been set on the current instance. The clone will be completely
+        unevaluated, even if the current instance has been partially or
+        completely evaluated.
+        """
         copy = Cursor(self.__collection, self.__spec, self.__fields,
                       self.__skip, self.__limit)
+        copy.__slave_okay = self.__slave_okay
         copy.__ordering = self.__ordering
         copy.__explain = self.__explain
         copy.__hint = self.__hint
+        copy.__socket = self.__socket
         return copy
 
     def __die(self):
@@ -92,13 +126,11 @@ class Cursor(object):
 
     def __query_options(self):
         """Get the 4 byte query options string to use for this query.
-
-        None = 0
-        CursorTailable = 2
-        SlaveOk = 4
-        OplogReplay = 8
         """
-        return struct.pack("<I", 0)
+        options = 0
+        if self.__slave_okay:
+            options |= _QUERY_OPTIONS["slave_okay"]
+        return struct.pack("<I", options)
 
     def __check_okay_to_chain(self):
         """Check if it is okay to chain more options onto this cursor.
@@ -106,6 +138,30 @@ class Cursor(object):
         if self.__retrieved or self.__id is not None:
             raise InvalidOperation("cannot set options after executing query")
 
+    def slave_okay(self, slave_okay=True):
+        """Specify whether this query should be allowed to execute on a slave.
+
+        By default, certain queries are not allowed to execute on mongod
+        instances running in slave mode. If `slave_okay` is True then this
+        query will be allowed to execute on slave instances. If False, the
+        default behavior applies.
+
+        Settings made through calls to this method take precedence over any
+        settings made elsewhere (like the slave_okay option when creating a
+        Connection). The last `slave_okay` applied to this cursor
+        takes precedence.
+
+        Raises InvalidOperation if this cursor has already been used.
+
+        :Parameters:
+          - `slave_okay` (optional): should this query be allowed to execute on
+            slave instances
+        """
+        self.__check_okay_to_chain()
+
+        self.__slave_okay = slave_okay
+        return self
+
     def limit(self, limit):
         """Limits the number of results to be returned by this cursor.
 
@@ -182,11 +238,22 @@ class Cursor(object):
     def explain(self):
         """Returns an explain plan record for this cursor.
         """
-        c = self.__copy()
+        c = self.clone()
         c.__explain = True
         return c.next()
 
-    def hint(self, index_or_name):
+    def __index_name_to_list(self, index_name):
+        """Convert an index specified by name to an index spec list.
+        """
+        # NOTE this is broken for indexes on key names containing '_'
+        index_list = []
+        tokens = index_name.split("_")
+        for key, direction in zip(tokens[::2], tokens[1::2]):
+            index_list.append((key, int(direction)))
+        return index_list
+
+    # TODO at some point fully deprecate index name - it could be buggy
+    def hint(self, index):
         """Adds a 'hint', telling Mongo the proper index to use for the query.
 
         Judicious use of hints can greatly improve query performance. When
@@ -195,26 +262,28 @@ class Cursor(object):
         anything if the corresponding index does not exist. Raises
         InvalidOperation if this cursor has already been used.
 
-        `index_or_name` can be either an index name (as returned by
-        create_index) or an index (as passed to create_index). If index_or_name
-        is None any existing hints for this query are cleared. The last hint
-        applied to this cursor takes precedence over all others.
+        `index` should be an index as passed to create_index
+        (e.g. [('field', ASCENDING)]). If `index` is None any existing
+        hints for this query are cleared. The last hint applied to this cursor
+        takes precedence over all others.
 
         :Parameters:
-          - `index_or_name`: index (or name of index) to hint on
+          - `index`: index to hint on (as an index specifier)
         """
         self.__check_okay_to_chain()
-        if index_or_name is None:
+        if index is None:
             self.__hint = None
             return self
 
-        if not isinstance(index_or_name, (types.StringTypes, types.ListType)):
+        if not isinstance(index, (types.StringTypes, types.ListType)):
             raise TypeError("hint takes an index name or "
                             "a list specifying an index")
-        name = index_or_name
-        if isinstance(name, types.ListType):
-            name = self.__collection._gen_index_name(name)
-        self.__hint = name
+        if isinstance(index, types.StringTypes):
+            warnings.warn("hinting using an index name is deprecated and will"
+                          " be removed - use a regular index spec instead",
+                          DeprecationWarning)
+            index = self.__index_name_to_list(index)
+        self.__hint = pymongo._index_document(index)
         return self
 
     def where(self, code):
