@@ -16,6 +16,7 @@
 import unittest
 import types
 import random
+import warnings
 import sys
 sys.path[0:0] = [""]
 
@@ -61,24 +62,41 @@ class TestCursor(unittest.TestCase):
 
         index = db.test.create_index("num", ASCENDING)
 
+        spec = [("num", ASCENDING)]
         self.assertEqual(db.test.find({}).explain()["cursor"], "BasicCursor")
-        self.assertEqual(db.test.find({}).hint(index).explain()["cursor"],
+        self.assertEqual(db.test.find({}).hint(spec).explain()["cursor"],
                          "BtreeCursor %s" % index)
-        self.assertEqual(db.test.find({}).hint(index).hint(None)
+        self.assertEqual(db.test.find({}).hint(spec).hint(None)
                          .explain()["cursor"],
                          "BasicCursor")
-        self.assertEqual(db.test.find({}).hint([("num", ASCENDING)])
-                         .explain()["cursor"],
-                         "BtreeCursor %s" % index)
         self.assertRaises(OperationFailure,
                           db.test.find({"num": 17, "foo": 17})
                           .hint([("foo", ASCENDING)]).explain)
 
         a = db.test.find({"num": 17})
-        a.hint(index)
+        a.hint(spec)
         for _ in a:
             break
-        self.assertRaises(InvalidOperation, a.hint, index)
+        self.assertRaises(InvalidOperation, a.hint, spec)
+
+        warnings.simplefilter("error")
+        self.assertRaises(DeprecationWarning, db.test.find().hint, index)
+
+    # TODO right now this doesn't actually test anything useful, just that the
+    # call doesn't blow up in the normal case.
+    def test_slave_okay(self):
+        db = self.db
+        db.drop_collection("test")
+
+        a = db.test.find()
+        for _ in a:
+            break
+        self.assertRaises(InvalidOperation, a.slave_okay)
+
+        db.test.save({"x": 1})
+        self.assertEqual(1, db.test.find().slave_okay().next()["x"])
+        self.assertEqual(1, db.test.find().slave_okay(False).next()["x"])
+        self.assertEqual(1, db.test.find().slave_okay(True).next()["x"])
 
     def test_limit(self):
         db = self.db
@@ -349,5 +367,77 @@ class TestCursor(unittest.TestCase):
         self.assertEqual(by_location,
                          db._command({"cursorInfo": 1})["byLocation_size"])
 
+    def test_rewind(self):
+        self.db.test.save({"x": 1})
+        self.db.test.save({"x": 2})
+        self.db.test.save({"x": 3})
+
+        cursor = self.db.test.find().limit(2)
+
+        count = 0
+        for _ in cursor:
+            count += 1
+        self.assertEqual(2, count)
+
+        count = 0
+        for _ in cursor:
+            count += 1
+        self.assertEqual(0, count)
+
+        cursor.rewind()
+        count = 0
+        for _ in cursor:
+            count += 1
+        self.assertEqual(2, count)
+
+        cursor.rewind()
+        count = 0
+        for _ in cursor:
+            break
+        cursor.rewind()
+        for _ in cursor:
+            count += 1
+        self.assertEqual(2, count)
+
+        self.assertEqual(cursor, cursor.rewind())
+
+    def test_clone(self):
+        self.db.test.save({"x": 1})
+        self.db.test.save({"x": 2})
+        self.db.test.save({"x": 3})
+
+        cursor = self.db.test.find().limit(2)
+
+        count = 0
+        for _ in cursor:
+            count += 1
+        self.assertEqual(2, count)
+
+        count = 0
+        for _ in cursor:
+            count += 1
+        self.assertEqual(0, count)
+
+        cursor = cursor.clone()
+        cursor2 = cursor.clone()
+        count = 0
+        for _ in cursor:
+            count += 1
+        self.assertEqual(2, count)
+        for _ in cursor2:
+            count += 1
+        self.assertEqual(4, count)
+
+        cursor.rewind()
+        count = 0
+        for _ in cursor:
+            break
+        cursor = cursor.clone()
+        for _ in cursor:
+            count += 1
+        self.assertEqual(2, count)
+
+        self.assertNotEqual(cursor, cursor.clone())
+
 if __name__ == "__main__":
     unittest.main()
