@@ -38,17 +38,22 @@ class TestMasterSlaveConnection(unittest.TestCase):
         try:
             self.slaves.append(Connection(os.environ.get("DB_IP2", host),
                                           int(os.environ.get("DB_PORT2",
-                                                             27018))))
+                                                             27018)),
+                                          slave_okay=True))
         except ConnectionFailure:
             pass
 
         try:
             self.slaves.append(Connection(os.environ.get("DB_IP3", host),
                                           int(os.environ.get("DB_PORT3",
-                                                             27019))))
+                                                             27019)),
+                                          slave_okay=True))
         except ConnectionFailure:
             pass
 
+        if not self.slaves:
+            raise SkipTest()
+
         self.connection = MasterSlaveConnection(self.master, self.slaves)
         self.db = self.connection.pymongo_test
 
